@@ -70,7 +70,8 @@ checkwavs <- function(X = NULL, path = NULL) {
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
     if (!dir.exists(path)) 
-      stop("'path' provided does not exist") 
+      stop("'path' provided does not exist") else
+        path <- normalizePath(path) 
   
   #return warning if not all sound files were found
   files <- list.files(path = path, pattern = "\\.wav$", ignore.case = TRUE)
