@@ -83,11 +83,14 @@ cut_sels <- function(X, mar = 0.05, parallel = 1, path = NULL, dest.path = NULL,
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
     if (!dir.exists(path)) 
-      stop("'path' provided does not exist") 
+      stop("'path' provided does not exist") else
+        path <- normalizePath(path)
   
   #check path to destiny directory
   if (!is.null(dest.path))
-  {if (!dir.exists(dest.path)) stop("'dest.path' provided does not exist")} else dest.path <- path
+  {if (!dir.exists(dest.path)) stop("'dest.path' provided does not exist") else
+    dest.path <- normalizePath(dest.path)
+    } else dest.path <- path
    
   #if X is not a data frame
   if (!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
