@@ -127,7 +127,8 @@ lspec <- function(X = NULL, flim = c(0, 22), sxrow = 5, rows = 10, collevels = s
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
     if (!dir.exists(path)) 
-      stop("'path' provided does not exist") 
+      stop("'path' provided does not exist") else
+        path <- normalizePath(path)
   
   #if sel.comment column not found create it
   if (is.null(X$sel.comment) & !is.null(X)) X<-data.frame(X,sel.comment="")
