@@ -76,7 +76,8 @@ lspec2pdf <- function(keep.img = TRUE, overwrite = FALSE, parallel = 1, path = N
   #check path to working directory
   if (is.null(path)) 
     path <- getwd() else
-    if (!dir.exists(path)) stop("'path' provided does not exist")
+    if (!dir.exists(path)) stop("'path' provided does not exist") else
+      path <- normalizePath(path)
   
   #list jpeg files
   imgs <- list.files(path = path, pattern = "\\.jpeg$", ignore.case = TRUE)
