@@ -143,7 +143,8 @@ manualoc <- function(wl = 512, flim = c(0,12), seltime = 1, tdisp = NULL, reccom
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
     if (!dir.exists(path)) 
-      stop("'path' provided does not exist") 
+      stop("'path' provided does not exist") else
+        path <- normalizePath(path)
   
   options(show.error.messages = TRUE) 
   files <- list.files(path = path, pattern = "\\.wav$", ignore.case = TRUE) #list .wav files in working director
