@@ -71,7 +71,8 @@ wav_info <- function(path = NULL, parallel = 1, pb = TRUE)
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
     if (!dir.exists(path)) 
-      stop("'path' provided does not exist") 
+      stop("'path' provided does not exist") else
+        path <- normalizePath(path)
     
   # make a selection table from files
   st <- selection_table(whole.recs = TRUE, path = path, parallel = parallel, pb = pb)
