@@ -122,7 +122,8 @@ xcorr <- function(X = NULL, wl = 512, bp = "pairwise.freq.range", ovlp = 70, den
   #check path to working directory
   if (is.null(path)) path <- getwd() else 
     if (!dir.exists(path) & !is_extended_selection_table(X)) 
-      stop("'path' provided does not exist")
+      stop("'path' provided does not exist") else
+        path <- normalizePath(path)
   
   #if X is not a data frame
   if (!any(is.data.frame(X), is_selection_table(X), is_extended_selection_table(X))) stop("X is not of a class 'data.frame', 'selection_table' or 'extended_selection_table'")
